@@ -20,20 +20,21 @@
 #ifndef CHECKOUTDIALOG_H
 #define CHECKOUTDIALOG_H
 
-#include <kdialog.h>
+#include <QDialog>
 #include <QSet>
 #include <QString>
 
-class KComboBox;
-class KLineEdit;
 class QCheckBox;
+class QComboBox;
+class QDialogButtonBox;
 class QGroupBox;
+class QLineEdit;
 class QRadioButton;
 
 /**
  * @brief The dialog for checking out Branches or Tags in Git.
  */
-class CheckoutDialog : public KDialog
+class CheckoutDialog : public QDialog
 {
     Q_OBJECT
 
@@ -76,12 +77,13 @@ private:
     bool m_userEditedNewBranchName;
     QSet<QString> m_branchNames;
     QPalette m_errorColors;
+    QDialogButtonBox *m_buttonBox;
     QGroupBox * m_branchSelectGroupBox;
     QRadioButton * m_branchRadioButton;
-    KComboBox * m_branchComboBox;
-    KComboBox * m_tagComboBox;
+    QComboBox * m_branchComboBox;
+    QComboBox * m_tagComboBox;
     QCheckBox * m_newBranchCheckBox;
-    KLineEdit * m_newBranchName;
+    QLineEdit * m_newBranchName;
     QCheckBox * m_forceCheckBox;
 };
 
